format = _("%s is deprecated. Use %s instead.")
warning(format % ["slide-background", "slide-background-image"])
include_theme("slide-background-image")
